@@ -2,12 +2,13 @@
 File controller class with inheritted classes for each type of file.
 """
 from _common import *
-import os, shutil, json, zipfile
+import os, shutil, json, zipfile, unicodedata
 import HTMLParser
 import _template_renderer as tr
 import re, base64, hashlib, pwd, subprocess
 from download import download_libraries
-from _git import Change2Directory
+import _git
+
             
 def new_repo_path(repo):
     """
@@ -20,11 +21,11 @@ def new_repo_path(repo):
     return repo, repo_path
 
 def repeat_owners_permission(path = REPOS_DIR):
-    subprocess.call('chmod -R a+u %s' % path, shell=True)
+    _git.repeat_owners_permission(path)
     
 def zip_dir(path2zip, zip_file_path, arcfolder, path_check = None):
     zipf = zipfile.ZipFile(zip_file_path, 'w')
-    with Change2Directory(path2zip):
+    with _git.Change2Directory(path2zip):
         for root, _, files in os.walk('.'):
             for f in files:
                 file_path = os.path.join(root, f)
@@ -113,6 +114,7 @@ class _File_Controller(object):
         self.cfiles = {}
         for cf in self._get_all_files():
             self.cfiles[cf.id] = cf
+        self.cfiles_ordered = sorted([(k, v) for k, v in self.cfiles.items()], key=lambda (k ,v): v.display)
     
     def _file_test(self, fn):
         """
@@ -154,8 +156,15 @@ class _File_Controller(object):
     
     def write_file(self, content, repo, name):
         cfile = self.create_cfile(repo, name)
+        if isinstance(content, unicode) or isinstance(content, str):
+            content = self._sanitize(content)
         cfile.write_file(content)
         return cfile
+        
+    def _sanitize(self, text):
+        if not isinstance(text, unicode):
+            text = unicode(str(text).decode('utf8'))
+        return unicodedata.normalize('NFKD', text).encode('ascii', 'ignore')
     
     def create_cfile(self, repo, name):
         self.active_cfile = _File(repo, self.DIR, self._valid_name(name))
@@ -247,7 +256,12 @@ class Pages(_File_Controller):
     
     def get_true_context(self):
         context = {}
-        for name, item in self.get_empty_context().items():
+        try:
+            empty_con = self.get_empty_context()
+        except Exception, e:
+            print 'Error getting empty context: %s' % str(e)
+            return 
+        for name, item in empty_con.items():
             context[name] = item
             if name in self.active_cfile.info['context']:
                 context[name]['value'] = self.active_cfile.info['context'][name]['value']
@@ -261,7 +275,7 @@ class Pages(_File_Controller):
         return context
     
     def update_context(self, fields, f_types):
-        print fields
+#         print fields
         context = {}
         if 'extension' in fields:
             self.active_cfile.info['extension'] = fields['extension']
@@ -270,7 +284,7 @@ class Pages(_File_Controller):
         for name, item in self.get_empty_context().items():
             if name in fields:
                 context[name] = item
-                text = fields[name]
+                text = self._sanitize(fields[name])
                 if item['type'] in ['html', 'markdown']:
                     text = HTMLParser.HTMLParser().unescape(text)
                 context[name]['value'] = text
