@@ -10,10 +10,8 @@ sg = ds.SiteGenerator
 THIS_PATH = os.path.dirname(os.path.realpath(__file__))
 EDITOR_TEMPLATE_DIR = os.path.join(THIS_PATH, 'templates') 
 
-static_urls = ('static/(.+)$', 'static_file')
 urls = (
     ('logout$', 'logout'),
-    static_urls,
     ('add-repo', 'edit_repo'),
     ('view-repo-(.+)$', 'view_repo'),
     ('add-page$', 'edit_page'),
@@ -44,14 +42,19 @@ class View(object):
     response_code = ''
     page = ''
     
-    def __init__(self,):
+    def __init__(self):
         self._msgs = {}
         self._env = jinja2.Environment(loader=jinja2.FileSystemLoader(EDITOR_TEMPLATE_DIR))
-        uri = os.environ['REQUEST_URI']
-        self._site_uri = uri[:uri.index('/edit/')]
+        self._uri = os.environ['REQUEST_URI']
+        self._site_uri = self._uri[:self._uri.index('/edit/')]
         print 'site_uri:', self._site_uri
-        e_index = uri.index('/edit/') + 5
-        self._site_edit_uri = uri[:e_index] + '/'
+        if hasattr(settings, 'SITE_URI'):
+            set_site_uri = settings.SITE_URI
+            if self._site_uri != set_site_uri:
+                self._add_msg('Auto detected URI does not match settings.SITE_URI: "%s" vs. "%s"'\
+                               % (self._site_uri, set_site_uri), 'warnings')
+        e_index = self._uri.index('/edit/') + 5
+        self._site_edit_uri = self._uri[:e_index] + '/'
         self._edit_static_uri = join_uri(self._site_edit_uri, 'static/')
         fields = cgi.FieldStorage()
         valid_user = self._auth(fields)
@@ -66,7 +69,7 @@ class View(object):
                 AnonFormProcessor(self._add_msg, fields)
         except Exception, e:
             processing_error = e
-        self._generate_page(uri, loggedin = valid_user, error = processing_error)
+        self._generate_page(self._uri, loggedin = valid_user, error = processing_error)
         
     def _generate_page(self, uri, loggedin = False, error = None):
         self.context = {'title': '%s Editor' % settings.SITE_NAME, 'site_name': settings.SITE_NAME, 'site_title': '%s Editor' % settings.SITE_NAME, 
@@ -85,12 +88,6 @@ class View(object):
             if 'reset-password' in uri:
                 self.reset_password()
             else:
-                # currently unused as static files are handled with a symlink:
-#                 m = re.search(static_urls[0], uri)
-#                 if m:
-#                     self.static_file(m.group(1))
-#                 else:
-#                     self.login()
                 self.login()
         else:
             found = False
@@ -143,39 +140,14 @@ class View(object):
         self.all_users = auth.users
 #         self.o_usernames = auth.get_sorted_users()
         return True
-    
-    def static_file(self, uri_path):
-        """
-        Render a static file from within the installed directory
-        having made sure the path is inside static.
-        
-        Currently unused as static files are handled with a symlink
-        for performance reasons (serving static files using cgi is a bit
-        mad and predicably slow).
-        """
-        this_dir = os.path.dirname(os.path.realpath(__file__))
-        uri_path = uri_path.strip(' ?')
-        name = os.path.basename(uri_path)
-        d = ''
-        if os.path.dirname(uri_path).endswith('libs/ace'):
-            d = 'libs/ace'
-        elif os.path.dirname(uri_path).endswith('libs'):
-            d = 'libs'
-        path = os.path.join(this_dir, 'static', d, name)
-#         print path
-        if os.path.exists(path):
-            if path.endswith('.css'):
-                self.content_type = 'content-type: text/css\n'
-            if path.endswith('.js'):
-                self.content_type = 'content-type: text/javascript\n'
-            self._static_file =open(path, 'r').read()
-        else:
-            self._page_not_found()
             
     def json_response(self, rid):
+        self._json_response(self._msgs)
+        
+    def _json_response(self, data):
         self._template = self._env.get_template('json_response.json')
         self.content_type = 'content-type: application/json\n'
-        self.context['json_response'] = json.dumps(self._msgs, sort_keys=True, indent=2, separators=(',', ': '))
+        self.context['json_response'] = json.dumps(data, sort_keys=True, indent=2, separators=(',', ': '))
         
     def login(self):
         self._template = self._env.get_template('login.html')
@@ -195,23 +167,23 @@ class View(object):
         try:
             page_con = ds.con.Pages()
             self.context['pages'] = []
-            for cf in page_con.cfiles.values():
+            for _, cf in page_con.cfiles_ordered:
                 self.context['pages'].append({'link': 'edit-page-%s' % cf.id, 'name': cf.display})
             self.context['templates'] = []
             t = ds.con.Templates()
-            for cf in t.cfiles.values():
+            for _, cf in t.cfiles_ordered:
                 self.context['templates'].append({'link': 'edit-template-%s' % cf.id, 'name': cf.display})
             self.context['static_files'] = []
             s = ds.con.Statics()
-            for cf in s.cfiles.values():
+            for _, cf in s.cfiles_ordered:
                 self.context['static_files'].append({'link': 'edit-static-%s' % cf.id, 'name': cf.display})
             self.context['library_files'] = []
             s = ds.con.LibraryFiles()
-            for cf in s.cfiles.values():
+            for _, cf in s.cfiles_ordered:
                 self.context['library_files'].append({'link': 'edit-libfile-%s' % cf.id, 'name': cf.display})
             self.context['globcon_files'] = []
             gc = ds.con.GlobConFiles()
-            for cf in gc.cfiles.values():
+            for _, cf in gc.cfiles_ordered:
                 self.context['globcon_files'].append({'link': 'edit-globcon-%s' % cf.id, 'name': cf.display})
             if self.isadmin:
                 self.context['users'] = []
@@ -247,7 +219,6 @@ class View(object):
         self.edit_page(self.created_item)
     
     def edit_page(self, pid):
-        print 'pid:', pid
         t_con = ds.con.Templates()
         self.context['page_templates'] = t_con.cfiles.values()
         self.context['other_formats'] = ['markdown', 'html']
@@ -259,6 +230,7 @@ class View(object):
             except:
                 return self._error_page('Page not found', code=httplib.BAD_REQUEST)
             self.context['page_name'] = cfile.info['name']
+            self.context['active_repo'] = cfile.repo
             if 'sitemap' in cfile.info:
                 self.context['sitemap'] = cfile.info['sitemap']
             if 'extension' in cfile.info:
@@ -267,30 +239,36 @@ class View(object):
             self.context['page_context_str'] = []
             self.context['page_context_other'] = []
             global_context = ds.SiteGenerator().global_context()
-            for name, value in page_con.get_true_context().items():
-                override = True
-                global_var = name in global_context
-                if value['value'] == None:
-                    value['value'] = ''
-                    if global_var:
-                        override = False
-                con_settings = {'name': name, 
-                                'value': value['value'], 
-                                'type': value['type'], 
-                                'override': override,
-                                'global_var': global_var}
-                if value['type'] == 'string':
-                    self.context['page_context_str'].append(con_settings)
-                else:
-                    con_settings['value'] = cgi.escape(value['value'])
-                    self.context['page_context_other'].append(con_settings)
-            self.context['active_page_template_id'] = t_con.get_cfile_name(name = cfile.info['template'], repo = cfile.info['template_repo']).id
+            true_context = page_con.get_true_context()
+            if true_context is None:
+                self._add_msg('Problem getting template context', 'errors')
+            else:
+                for name, value in true_context.items():
+                    override = True
+                    global_var = name in global_context
+                    if value['value'] == None:
+                        value['value'] = ''
+                        if global_var:
+                            override = False
+                    con_settings = {'name': name, 
+                                    'value': value['value'], 
+                                    'type': value['type'], 
+                                    'override': override,
+                                    'global_var': global_var}
+                    if value['type'] == 'string':
+                        self.context['page_context_str'].append(con_settings)
+                    else:
+                        con_settings['value'] = cgi.escape(value['value'])
+                        self.context['page_context_other'].append(con_settings)
+            try:
+                self.context['active_page_template_id'] = t_con.get_cfile_name(name = cfile.info['template'], repo = cfile.info['template_repo']).id
+            except Exception, e:
+                self._add_msg('Problem getting template id: %s' % str(e), 'errors')
             self.context['action_uri'] = self.context['edit_uri']
         self._template = self._env.get_template('edit_page.html')
     
     def edit_template(self, tid):
         def generate_global_vars(var_tree):
-            print var_tree
             for name, value in var_tree.items():
                 if type(value) == dict:
                     for name2, value2 in value.items():
@@ -438,7 +416,10 @@ class View(object):
         if error_details:
             self.context['error_details'] = str(error_details)
             traceback.print_exc()
-        self._template = self._env.get_template('bad.html')
+        if 'submit.json' in self._uri:
+            self._json_response(self.context)
+        else:
+            self._template = self._env.get_template('bad.html')
     
     def _add_msg(self, msg, mtype='info'):
         if mtype not in self._msgs:
